==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AlignRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescriptionMetadata } from "./FormatRadialGaugeLabelEventArgsDescriptionMetadata";
import { AlignRadialGaugeLabelEventArgsDescription } from "./AlignRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var AlignRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AlignRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function AlignRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (AlignRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.c(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.g(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        AlignRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.u("AlignRadialGaugeLabelEventArgs", function () { return new AlignRadialGaugeLabelEventArgsDescription(); });
        a.t("AlignRadialGaugeLabelEventArgs", AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(AlignRadialGaugeLabelEventArgsDescriptionMetadata, 'AlignRadialGaugeLabelEventArgsDescriptionMetadata');
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return AlignRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { AlignRadialGaugeLabelEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AlignRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescriptionMetadata } from "./FormatRadialGaugeLabelEventArgsDescriptionMetadata";
import { AlignRadialGaugeLabelEventArgsDescription } from "./AlignRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var AlignRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AlignRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function AlignRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (AlignRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.c(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.j(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        AlignRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.aa("AlignRadialGaugeLabelEventArgs", function () { return new AlignRadialGaugeLabelEventArgsDescription(); });
        a.z("AlignRadialGaugeLabelEventArgs", AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(AlignRadialGaugeLabelEventArgsDescriptionMetadata, 'AlignRadialGaugeLabelEventArgsDescriptionMetadata');
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return AlignRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { AlignRadialGaugeLabelEventArgsDescriptionMetadata };
